@@ -6,7 +6,7 @@
 #   2. grep -v '^ *#line' | grep -v '^#'
 #   3. sed -e 's,% ,%,g' -e 's,//,@,g' -e 's,\$,#,g'
 
-# Copyright (C) 1999-2017 Bruno Haible <bruno@clisp.org>
+# Copyright (C) 1999-2022 Bruno Haible <bruno@clisp.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,12 +19,12 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 tmpscript1=sed$$tmp1
 tmpscript2=sed$$tmp2
 tmpremove='rm -f $tmpscript1 $tmpscript2'
-trap "$tmpremove" 1 2 15
+trap "$tmpremove" HUP INT TERM
 
 cat > $tmpscript1 << \EOF
 # ----------- Remove gcc self-identification
@@ -39,9 +39,14 @@ s,@,//,g
 # ----------- Turn # into $, to avoid trouble in preprocessing
 s,#,\$,g
 # ----------- Global symbols depends on ASM_UNDERSCORE
+/[ 	]\.req[ 	]/!{
 s/^\([A-Za-z0-9_]\+\)/C(\1)/
+}
 s/\.L\([A-Za-z0-9_]\+\)/L(\1)/
 s/\.global[ 	]\([A-Za-z0-9_]*\)/.global C(\1)/
+# ----------- Eliminate assembler pseudo-ops that allowed old syntax for inline
+#             asms but that are not understood by the FreeBSD assembler
+/\.syntax divided/d
 # ----------- Introduce macro syntax for assembler pseudo-ops
 /\.file\([ 	]\+\)/d
 /\.section\([ 	]\+\).*GNU-stack/d
